FlutterFlowApi class
The FlutterFlowApi class provides methods for exporting code from a
FlutterFlow project.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
export(
{required String token, required String projectId, required String destinationPath, required bool includeAssets, String endpoint = kDefaultEndpoint, String? branchName, String? environmentName, String? commitHash, bool unzipToParentFolder = false, bool fix = false, bool exportAsModule = false, bool format = true, bool exportAsDebug = false, bool includeExportManifest = false}) → Future< String?> - Exports the code from a FlutterFlow project.